/*
 * Copyright (C) 2015 Infineon Technologies AG. All rights reserved.
 *
 * Infineon Technologies AG (Infineon) is supplying this software for use with
 * Infineon's microcontrollers.
 * This file can be freely distributed within development tools that are
 * supporting such microcontrollers.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS". NO WARRANTIES, WHETHER EXPRESS, IMPLIED
 * OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
 * INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL,
 * OR CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
 *
 */

/**
 * @file xmc1_usic_map.h
 * @date 16 Feb, 2015
 * @version 1.0.0
 *
 * @brief XMC1 USIC mapping definitions
 *
 * History <br>
 *
 * Version 1.0.0 Initial <br>
 */

#ifndef XMC1_USIC_MAP_H
#define XMC1_USIC_MAP_H

/*******************************************************************************
 * MACROS
 *******************************************************************************/

#define USIC_INPUT_ALWAYS_1     7

#if (UC_DEVICE == XMC1100) && (UC_PACKAGE == VQFN24)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif


#if (UC_DEVICE == XMC1100) && (UC_PACKAGE == VQFN40)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_10  	2
#define USIC0_C0_DX2_P0_11  	3
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_4   	1
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_4   	1
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P1_4   	4
#define USIC0_C0_DX5_P1_6   	5
#define USIC0_C0_DX5_P2_3   	1
#define USIC0_C0_DX5_P2_5   	3
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_10  	2
#define USIC0_C1_DX2_P0_11  	3
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_3   	2
#define USIC0_C1_DX3_P2_5   	4
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_3   	2
#define USIC0_C1_DX4_P2_5   	4
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P1_4   	4
#define USIC0_C1_DX5_P1_5   	5
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_4   	1
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif


#if (UC_DEVICE == XMC1100) && (UC_PACKAGE == TSSOP16)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif


#if (UC_DEVICE == XMC1100) && (UC_PACKAGE == TSSOP38)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_10  	2
#define USIC0_C0_DX2_P0_11  	3
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_4   	1
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_4   	1
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P1_4   	4
#define USIC0_C0_DX5_P2_3   	1
#define USIC0_C0_DX5_P2_5   	3
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_10  	2
#define USIC0_C1_DX2_P0_11  	3
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_3   	2
#define USIC0_C1_DX3_P2_5   	4
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_3   	2
#define USIC0_C1_DX4_P2_5   	4
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P1_4   	4
#define USIC0_C1_DX5_P1_5   	5
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_4   	1
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif


#if (UC_DEVICE == XMC1200) && (UC_PACKAGE == TSSOP38)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_10  	2
#define USIC0_C0_DX2_P0_11  	3
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_4   	1
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_4   	1
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P1_4   	4
#define USIC0_C0_DX5_P2_3   	1
#define USIC0_C0_DX5_P2_5   	3
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_10  	2
#define USIC0_C1_DX2_P0_11  	3
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_3   	2
#define USIC0_C1_DX3_P2_5   	4
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_3   	2
#define USIC0_C1_DX4_P2_5   	4
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P1_4   	4
#define USIC0_C1_DX5_P1_5   	5
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_4   	1
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif


#if (UC_DEVICE == XMC1201) && (UC_PACKAGE == VQFN40)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_10  	2
#define USIC0_C0_DX2_P0_11  	3
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_4   	1
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_4   	1
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P1_4   	4
#define USIC0_C0_DX5_P1_6   	5
#define USIC0_C0_DX5_P2_3   	1
#define USIC0_C0_DX5_P2_5   	3
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_10  	2
#define USIC0_C1_DX2_P0_11  	3
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_3   	2
#define USIC0_C1_DX3_P2_5   	4
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_3   	2
#define USIC0_C1_DX4_P2_5   	4
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P1_4   	4
#define USIC0_C1_DX5_P1_5   	5
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_4   	1
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif


#if (UC_DEVICE == XMC1201) && (UC_PACKAGE == TSSOP38)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_10  	2
#define USIC0_C0_DX2_P0_11  	3
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_4   	1
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_4   	1
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P1_4   	4
#define USIC0_C0_DX5_P2_3   	1
#define USIC0_C0_DX5_P2_5   	3
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_10  	2
#define USIC0_C1_DX2_P0_11  	3
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_3   	2
#define USIC0_C1_DX3_P2_5   	4
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_3   	2
#define USIC0_C1_DX4_P2_5   	4
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P1_4   	4
#define USIC0_C1_DX5_P1_5   	5
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_4   	1
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif


#if (UC_DEVICE == XMC1202) && (UC_PACKAGE == VQFN24)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif


#if (UC_DEVICE == XMC1202) && (UC_PACKAGE == VQFN40)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_10  	2
#define USIC0_C0_DX2_P0_11  	3
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_4   	1
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_4   	1
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P1_4   	4
#define USIC0_C0_DX5_P1_6   	5
#define USIC0_C0_DX5_P2_3   	1
#define USIC0_C0_DX5_P2_5   	3
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_10  	2
#define USIC0_C1_DX2_P0_11  	3
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_3   	2
#define USIC0_C1_DX3_P2_5   	4
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_3   	2
#define USIC0_C1_DX4_P2_5   	4
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P1_4   	4
#define USIC0_C1_DX5_P1_5   	5
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_4   	1
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif


#if (UC_DEVICE == XMC1202) && (UC_PACKAGE == TSSOP16)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif


#if (UC_DEVICE == XMC1202) && (UC_PACKAGE == TSSOP28)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_10  	2
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P2_5   	3
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_10  	2
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_5   	4
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_5   	4
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif


#if (UC_DEVICE == XMC1301) && (UC_PACKAGE == VQFN24)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif


#if (UC_DEVICE == XMC1301) && (UC_PACKAGE == VQFN40)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_10  	2
#define USIC0_C0_DX2_P0_11  	3
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_4   	1
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_4   	1
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P1_4   	4
#define USIC0_C0_DX5_P1_6   	5
#define USIC0_C0_DX5_P2_3   	1
#define USIC0_C0_DX5_P2_5   	3
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_10  	2
#define USIC0_C1_DX2_P0_11  	3
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_3   	2
#define USIC0_C1_DX3_P2_5   	4
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_3   	2
#define USIC0_C1_DX4_P2_5   	4
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P1_4   	4
#define USIC0_C1_DX5_P1_5   	5
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_4   	1
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif


#if (UC_DEVICE == XMC1301) && (UC_PACKAGE == TSSOP16)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif


#if (UC_DEVICE == XMC1301) && (UC_PACKAGE == TSSOP38)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_10  	2
#define USIC0_C0_DX2_P0_11  	3
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_4   	1
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_4   	1
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P1_4   	4
#define USIC0_C0_DX5_P2_3   	1
#define USIC0_C0_DX5_P2_5   	3
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_10  	2
#define USIC0_C1_DX2_P0_11  	3
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_3   	2
#define USIC0_C1_DX3_P2_5   	4
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_3   	2
#define USIC0_C1_DX4_P2_5   	4
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P1_4   	4
#define USIC0_C1_DX5_P1_5   	5
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_4   	1
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif


#if (UC_DEVICE == XMC1302) && (UC_PACKAGE == VQFN24)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif


#if (UC_DEVICE == XMC1302) && (UC_PACKAGE == VQFN40)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_10  	2
#define USIC0_C0_DX2_P0_11  	3
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_4   	1
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_4   	1
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P1_4   	4
#define USIC0_C0_DX5_P1_6   	5
#define USIC0_C0_DX5_P2_3   	1
#define USIC0_C0_DX5_P2_5   	3
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_10  	2
#define USIC0_C1_DX2_P0_11  	3
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_3   	2
#define USIC0_C1_DX3_P2_5   	4
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_3   	2
#define USIC0_C1_DX4_P2_5   	4
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P1_4   	4
#define USIC0_C1_DX5_P1_5   	5
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_4   	1
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif


#if (UC_DEVICE == XMC1302) && (UC_PACKAGE == TSSOP16)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif


#if (UC_DEVICE == XMC1302) && (UC_PACKAGE == TSSOP38)
#define USIC0_C0_DX0_DX3INS 	6
#define USIC0_C0_DX0_P0_14  	0
#define USIC0_C0_DX0_P0_15  	1
#define USIC0_C0_DX0_P1_0   	2
#define USIC0_C0_DX0_P1_1   	3
#define USIC0_C0_DX0_P2_0   	4
#define USIC0_C0_DX0_P2_1   	5
#define USIC0_C0_DX1_DX0INS 	5
#define USIC0_C0_DX1_DX4INS 	6
#define USIC0_C0_DX1_P0_14  	0
#define USIC0_C0_DX1_P0_7   	2
#define USIC0_C0_DX1_P0_8   	1
#define USIC0_C0_DX1_P1_1   	3
#define USIC0_C0_DX1_P2_0   	4
#define USIC0_C0_DX2_DX5INS 	6
#define USIC0_C0_DX2_P0_0   	0
#define USIC0_C0_DX2_P0_10  	2
#define USIC0_C0_DX2_P0_11  	3
#define USIC0_C0_DX2_P0_12  	4
#define USIC0_C0_DX2_P0_13  	5
#define USIC0_C0_DX2_P0_9   	1
#define USIC0_C0_DX3_DOUT0  	6
#define USIC0_C0_DX3_DX5INS 	5
#define USIC0_C0_DX3_P2_10  	2
#define USIC0_C0_DX3_P2_2   	0
#define USIC0_C0_DX3_P2_4   	1
#define USIC0_C0_DX3_P2_6   	4
#define USIC0_C0_DX3_P2_8   	3
#define USIC0_C0_DX4_DX5INS 	5
#define USIC0_C0_DX4_P2_10  	2
#define USIC0_C0_DX4_P2_2   	0
#define USIC0_C0_DX4_P2_4   	1
#define USIC0_C0_DX4_P2_6   	4
#define USIC0_C0_DX4_P2_8   	3
#define USIC0_C0_DX4_SCLKOUT	6
#define USIC0_C0_DX5_P1_4   	4
#define USIC0_C0_DX5_P2_3   	1
#define USIC0_C0_DX5_P2_5   	3
#define USIC0_C0_DX5_P2_7   	2
#define USIC0_C0_DX5_P2_9   	0
#define USIC0_C0_DX5_SELO0  	6
#define USIC0_C1_DX0_DX3INS 	6
#define USIC0_C1_DX0_P0_6   	2
#define USIC0_C1_DX0_P0_7   	3
#define USIC0_C1_DX0_P1_2   	1
#define USIC0_C1_DX0_P1_3   	0
#define USIC0_C1_DX0_P2_10  	5
#define USIC0_C1_DX0_P2_11  	4
#define USIC0_C1_DX1_DX0INS 	5
#define USIC0_C1_DX1_DX4INS 	6
#define USIC0_C1_DX1_P0_7   	2
#define USIC0_C1_DX1_P0_8   	1
#define USIC0_C1_DX1_P1_3   	0
#define USIC0_C1_DX1_P2_11  	4
#define USIC0_C1_DX2_DX5INS 	6
#define USIC0_C1_DX2_P0_0   	0
#define USIC0_C1_DX2_P0_10  	2
#define USIC0_C1_DX2_P0_11  	3
#define USIC0_C1_DX2_P0_9   	1
#define USIC0_C1_DX2_P1_1   	4
#define USIC0_C1_DX2_P2_0   	5
#define USIC0_C1_DX3_DOUT0  	6
#define USIC0_C1_DX3_DX5INS 	5
#define USIC0_C1_DX3_P2_1   	0
#define USIC0_C1_DX3_P2_3   	2
#define USIC0_C1_DX3_P2_5   	4
#define USIC0_C1_DX3_P2_7   	3
#define USIC0_C1_DX3_P2_9   	1
#define USIC0_C1_DX4_DX5INS 	5
#define USIC0_C1_DX4_P2_1   	0
#define USIC0_C1_DX4_P2_3   	2
#define USIC0_C1_DX4_P2_5   	4
#define USIC0_C1_DX4_P2_7   	3
#define USIC0_C1_DX4_P2_9   	1
#define USIC0_C1_DX4_SCLKOUT	6
#define USIC0_C1_DX5_P1_4   	4
#define USIC0_C1_DX5_P1_5   	5
#define USIC0_C1_DX5_P2_2   	0
#define USIC0_C1_DX5_P2_4   	1
#define USIC0_C1_DX5_P2_6   	3
#define USIC0_C1_DX5_P2_8   	2
#define USIC0_C1_DX5_SR0    	6
#endif

#endif /* XMC1_USIC_MAP_H */
