/*
 * Copyright (C) 2015 Infineon Technologies AG. All rights reserved.
 *
 * Infineon Technologies AG (Infineon) is supplying this software for use with Infineon's microcontrollers.
 * This file can be freely distributed within development tools that are supporting such microcontrollers.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS". NO WARRANTIES, WHETHER EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED
 * TO, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
 * INFINEON SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES, FOR ANY
 * REASON WHATSOEVER.
 *
 */

/**
 * @file xmc1_eru_map.h
 * @date 16 Feb, 2015
 * @version 1.0.0
 *
 * @brief XMC ERU mapping definitions
 *
 * History <br>
 *
 * Version 1.0.0 Initial version <br>
 */

#ifndef XMC1_ERU_MAP_H
#define XMC1_ERU_MAP_H

#define ERU0_ETL0 XMC_ERU0, 0
#define ERU0_ETL1 XMC_ERU0, 1
#define ERU0_ETL2 XMC_ERU0, 2
#define ERU0_ETL3 XMC_ERU0, 3

#define ERU0_OGU0 XMC_ERU0, 0
#define ERU0_OGU1 XMC_ERU0, 1
#define ERU0_OGU2 XMC_ERU0, 2
#define ERU0_OGU3 XMC_ERU0, 3

#if (UC_DEVICE == XMC1100) && (UC_PACKAGE == VQFN24)
#define ERU0_ETL0_INPUTA_ACMP0_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL0_INPUTA_ACMP2_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL0_INPUTB_ACMP0_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL0_INPUTB_P2_0              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL0_INPUTB_P2_2              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL1_INPUTA_ACMP1_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL1_INPUTA_ACMP3_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL1_INPUTB_ACMP1_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL1_INPUTB_P2_1              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL2_INPUTA_ACMP2_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL2_INPUTA_ACMP4_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL2_INPUTA_P2_6              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL2_INPUTB_ACMP2_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL2_INPUTB_P2_10             	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL2_INPUTB_P2_11             	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL3_INPUTA_ACMP5_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL3_INPUTA_ACMP7_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL3_INPUTA_P2_7              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL3_INPUTB_ACMP6_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL3_INPUTB_P2_8              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL3_INPUTB_P2_9              	XMC_ERU_ETL_INPUT_B0

#define ERU0_OGU0_PERIPHERAL_TRIGGER_CCU40_SR0	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU0_PERIPHERAL_TRIGGER_VADC_C0SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU1_PERIPHERAL_TRIGGER_CCU40_SR1	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU1_PERIPHERAL_TRIGGER_VADC_C0SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU2_PERIPHERAL_TRIGGER_CCU40_SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU2_PERIPHERAL_TRIGGER_VADC_C0SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU3_PERIPHERAL_TRIGGER_CCU40_SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU3_PERIPHERAL_TRIGGER_VADC_C0SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#endif


#if (UC_DEVICE == XMC1100) && (UC_PACKAGE == VQFN40)
#define ERU0_ETL0_INPUTA_ACMP0_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL0_INPUTA_ACMP2_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL0_INPUTA_P2_4              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL0_INPUTB_ACMP0_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL0_INPUTB_P2_0              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL0_INPUTB_P2_2              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL1_INPUTA_ACMP1_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL1_INPUTA_ACMP3_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL1_INPUTA_P2_5              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL1_INPUTB_ACMP1_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL1_INPUTB_P2_1              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL1_INPUTB_P2_3              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL2_INPUTA_ACMP2_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL2_INPUTA_ACMP4_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL2_INPUTA_P2_6              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL2_INPUTB_ACMP2_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL2_INPUTB_P2_10             	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL2_INPUTB_P2_11             	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL3_INPUTA_ACMP5_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL3_INPUTA_ACMP7_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL3_INPUTA_P2_7              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL3_INPUTB_ACMP6_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL3_INPUTB_P2_8              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL3_INPUTB_P2_9              	XMC_ERU_ETL_INPUT_B0

#define ERU0_OGU0_PERIPHERAL_TRIGGER_CCU40_SR0	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU0_PERIPHERAL_TRIGGER_VADC_C0SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU1_PERIPHERAL_TRIGGER_CCU40_SR1	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU1_PERIPHERAL_TRIGGER_VADC_C0SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU2_PERIPHERAL_TRIGGER_CCU40_SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU2_PERIPHERAL_TRIGGER_VADC_C0SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU3_PERIPHERAL_TRIGGER_CCU40_SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU3_PERIPHERAL_TRIGGER_VADC_C0SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#endif


#if (UC_DEVICE == XMC1100) && (UC_PACKAGE == TSSOP16)
#define ERU0_ETL0_INPUTA_ACMP0_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL0_INPUTA_ACMP2_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL0_INPUTB_ACMP0_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL0_INPUTB_P2_0              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL1_INPUTA_ACMP1_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL1_INPUTA_ACMP3_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL1_INPUTB_ACMP1_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL2_INPUTA_ACMP2_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL2_INPUTA_ACMP4_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL2_INPUTA_P2_6              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL2_INPUTB_ACMP2_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL2_INPUTB_P2_10             	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL2_INPUTB_P2_11             	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL3_INPUTA_ACMP5_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL3_INPUTA_ACMP7_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL3_INPUTA_P2_7              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL3_INPUTB_ACMP6_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL3_INPUTB_P2_8              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL3_INPUTB_P2_9              	XMC_ERU_ETL_INPUT_B0

#define ERU0_OGU0_PERIPHERAL_TRIGGER_CCU40_SR0	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU0_PERIPHERAL_TRIGGER_VADC_C0SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU1_PERIPHERAL_TRIGGER_CCU40_SR1	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU1_PERIPHERAL_TRIGGER_VADC_C0SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU2_PERIPHERAL_TRIGGER_CCU40_SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU2_PERIPHERAL_TRIGGER_VADC_C0SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU3_PERIPHERAL_TRIGGER_CCU40_SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU3_PERIPHERAL_TRIGGER_VADC_C0SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#endif


#if (UC_DEVICE == XMC1100) && (UC_PACKAGE == TSSOP38)
#define ERU0_ETL0_INPUTA_ACMP0_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL0_INPUTA_ACMP2_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL0_INPUTA_P2_4              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL0_INPUTB_ACMP0_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL0_INPUTB_P2_0              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL0_INPUTB_P2_2              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL1_INPUTA_ACMP1_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL1_INPUTA_ACMP3_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL1_INPUTA_P2_5              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL1_INPUTB_ACMP1_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL1_INPUTB_P2_1              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL1_INPUTB_P2_3              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL2_INPUTA_ACMP2_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL2_INPUTA_ACMP4_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL2_INPUTA_P2_6              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL2_INPUTB_ACMP2_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL2_INPUTB_P2_10             	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL2_INPUTB_P2_11             	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL3_INPUTA_ACMP5_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL3_INPUTA_ACMP7_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL3_INPUTA_P2_7              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL3_INPUTB_ACMP6_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL3_INPUTB_P2_8              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL3_INPUTB_P2_9              	XMC_ERU_ETL_INPUT_B0

#define ERU0_OGU0_PERIPHERAL_TRIGGER_CCU40_SR0	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU0_PERIPHERAL_TRIGGER_VADC_C0SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU1_PERIPHERAL_TRIGGER_CCU40_SR1	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU1_PERIPHERAL_TRIGGER_VADC_C0SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU2_PERIPHERAL_TRIGGER_CCU40_SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU2_PERIPHERAL_TRIGGER_VADC_C0SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU3_PERIPHERAL_TRIGGER_CCU40_SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU3_PERIPHERAL_TRIGGER_VADC_C0SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#endif


#if (UC_DEVICE == XMC1200) && (UC_PACKAGE == TSSOP38)
#define ERU0_ETL0_INPUTA_ACMP0_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL0_INPUTA_ACMP2_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL0_INPUTA_P2_4              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL0_INPUTA_VADC0_G0BFLOUT0   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL0_INPUTB_ACMP0_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL0_INPUTB_P2_0              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL0_INPUTB_P2_2              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL0_INPUTB_VADC0_G1BFLOUT0   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL1_INPUTA_ACMP1_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL1_INPUTA_ACMP3_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL1_INPUTA_P2_5              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL1_INPUTA_VADC0_G0BFLOUT1   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL1_INPUTB_ACMP1_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL1_INPUTB_P2_1              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL1_INPUTB_P2_3              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL1_INPUTB_VADC0_G1BFLOUT1   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL2_INPUTA_ACMP2_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL2_INPUTA_ACMP4_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL2_INPUTA_P2_6              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL2_INPUTA_VADC0_G0BFLOUT2   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL2_INPUTB_ACMP2_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL2_INPUTB_P2_10             	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL2_INPUTB_P2_11             	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL2_INPUTB_VADC0_G1BFLOUT2   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL3_INPUTA_ACMP5_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL3_INPUTA_ACMP7_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL3_INPUTA_P2_7              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL3_INPUTA_VADC0_G0BFLOUT3   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL3_INPUTB_ACMP6_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL3_INPUTB_P2_8              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL3_INPUTB_P2_9              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL3_INPUTB_VADC0_G1BFLOUT3   	XMC_ERU_ETL_INPUT_B3

#define ERU0_OGU0_PERIPHERAL_TRIGGER_CCU40_SR0	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU0_PERIPHERAL_TRIGGER_VADC_C0SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU1_PERIPHERAL_TRIGGER_CCU40_SR1	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU1_PERIPHERAL_TRIGGER_VADC_C0SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU2_PERIPHERAL_TRIGGER_CCU40_SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU2_PERIPHERAL_TRIGGER_VADC_C0SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU3_PERIPHERAL_TRIGGER_CCU40_SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU3_PERIPHERAL_TRIGGER_VADC_C0SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#endif


#if (UC_DEVICE == XMC1201) && (UC_PACKAGE == VQFN40)
#define ERU0_ETL0_INPUTA_ACMP2_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL0_INPUTA_P2_4              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL0_INPUTA_VADC0_G0BFLOUT0   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL0_INPUTB_ACMP0_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL0_INPUTB_P2_0              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL0_INPUTB_P2_2              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL0_INPUTB_VADC0_G1BFLOUT0   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL1_INPUTA_ACMP3_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL1_INPUTA_P2_5              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL1_INPUTA_VADC0_G0BFLOUT1   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL1_INPUTB_ACMP1_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL1_INPUTB_P2_1              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL1_INPUTB_P2_3              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL1_INPUTB_VADC0_G1BFLOUT1   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL2_INPUTA_ACMP4_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL2_INPUTA_P2_6              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL2_INPUTA_VADC0_G0BFLOUT2   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL2_INPUTB_ACMP2_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL2_INPUTB_P2_10             	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL2_INPUTB_P2_11             	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL2_INPUTB_VADC0_G1BFLOUT2   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL3_INPUTA_ACMP5_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL3_INPUTA_ACMP7_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL3_INPUTA_P2_7              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL3_INPUTA_VADC0_G0BFLOUT3   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL3_INPUTB_ACMP6_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL3_INPUTB_P2_8              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL3_INPUTB_P2_9              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL3_INPUTB_VADC0_G1BFLOUT3   	XMC_ERU_ETL_INPUT_B3

#define ERU0_OGU0_PERIPHERAL_TRIGGER_CCU40_SR0	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU0_PERIPHERAL_TRIGGER_VADC_C0SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU1_PERIPHERAL_TRIGGER_CCU40_SR1	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU1_PERIPHERAL_TRIGGER_VADC_C0SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU2_PERIPHERAL_TRIGGER_CCU40_SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU2_PERIPHERAL_TRIGGER_VADC_C0SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU3_PERIPHERAL_TRIGGER_CCU40_SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU3_PERIPHERAL_TRIGGER_VADC_C0SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#endif


#if (UC_DEVICE == XMC1201) && (UC_PACKAGE == TSSOP38)
#define ERU0_ETL0_INPUTA_ACMP2_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL0_INPUTA_P2_4              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL0_INPUTA_VADC0_G0BFLOUT0   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL0_INPUTB_ACMP0_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL0_INPUTB_P2_0              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL0_INPUTB_P2_2              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL0_INPUTB_VADC0_G1BFLOUT0   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL1_INPUTA_ACMP3_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL1_INPUTA_P2_5              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL1_INPUTA_VADC0_G0BFLOUT1   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL1_INPUTB_ACMP1_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL1_INPUTB_P2_1              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL1_INPUTB_P2_3              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL1_INPUTB_VADC0_G1BFLOUT1   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL2_INPUTA_ACMP4_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL2_INPUTA_P2_6              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL2_INPUTA_VADC0_G0BFLOUT2   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL2_INPUTB_ACMP2_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL2_INPUTB_P2_10             	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL2_INPUTB_P2_11             	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL2_INPUTB_VADC0_G1BFLOUT2   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL3_INPUTA_ACMP5_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL3_INPUTA_ACMP7_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL3_INPUTA_P2_7              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL3_INPUTA_VADC0_G0BFLOUT3   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL3_INPUTB_ACMP6_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL3_INPUTB_P2_8              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL3_INPUTB_P2_9              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL3_INPUTB_VADC0_G1BFLOUT3   	XMC_ERU_ETL_INPUT_B3

#define ERU0_OGU0_PERIPHERAL_TRIGGER_CCU40_SR0	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU0_PERIPHERAL_TRIGGER_VADC_C0SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU1_PERIPHERAL_TRIGGER_CCU40_SR1	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU1_PERIPHERAL_TRIGGER_VADC_C0SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU2_PERIPHERAL_TRIGGER_CCU40_SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU2_PERIPHERAL_TRIGGER_VADC_C0SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU3_PERIPHERAL_TRIGGER_CCU40_SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU3_PERIPHERAL_TRIGGER_VADC_C0SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#endif


#if (UC_DEVICE == XMC1202) && (UC_PACKAGE == VQFN24)
#define ERU0_ETL0_INPUTA_ACMP0_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL0_INPUTA_ACMP2_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL0_INPUTA_VADC0_G0BFLOUT0   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL0_INPUTB_ACMP0_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL0_INPUTB_P2_0              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL0_INPUTB_P2_2              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL0_INPUTB_VADC0_G1BFLOUT0   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL1_INPUTA_ACMP1_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL1_INPUTA_ACMP3_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL1_INPUTA_VADC0_G0BFLOUT1   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL1_INPUTB_ACMP1_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL1_INPUTB_P2_1              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL1_INPUTB_VADC0_G1BFLOUT1   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL2_INPUTA_ACMP2_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL2_INPUTA_ACMP4_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL2_INPUTA_P2_6              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL2_INPUTA_VADC0_G0BFLOUT2   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL2_INPUTB_ACMP2_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL2_INPUTB_P2_10             	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL2_INPUTB_P2_11             	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL2_INPUTB_VADC0_G1BFLOUT2   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL3_INPUTA_ACMP5_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL3_INPUTA_ACMP7_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL3_INPUTA_P2_7              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL3_INPUTA_VADC0_G0BFLOUT3   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL3_INPUTB_ACMP6_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL3_INPUTB_P2_8              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL3_INPUTB_P2_9              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL3_INPUTB_VADC0_G1BFLOUT3   	XMC_ERU_ETL_INPUT_B3

#define ERU0_OGU0_PERIPHERAL_TRIGGER_CCU40_SR0	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU0_PERIPHERAL_TRIGGER_VADC_C0SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU1_PERIPHERAL_TRIGGER_CCU40_SR1	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU1_PERIPHERAL_TRIGGER_VADC_C0SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU2_PERIPHERAL_TRIGGER_CCU40_SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU2_PERIPHERAL_TRIGGER_VADC_C0SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU3_PERIPHERAL_TRIGGER_CCU40_SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU3_PERIPHERAL_TRIGGER_VADC_C0SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#endif


#if (UC_DEVICE == XMC1202) && (UC_PACKAGE == VQFN40)
#define ERU0_ETL0_INPUTA_ACMP0_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL0_INPUTA_ACMP2_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL0_INPUTA_P2_4              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL0_INPUTA_VADC0_G0BFLOUT0   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL0_INPUTB_ACMP0_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL0_INPUTB_P2_0              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL0_INPUTB_P2_2              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL0_INPUTB_VADC0_G1BFLOUT0   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL1_INPUTA_ACMP1_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL1_INPUTA_ACMP3_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL1_INPUTA_P2_5              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL1_INPUTA_VADC0_G0BFLOUT1   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL1_INPUTB_ACMP1_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL1_INPUTB_P2_1              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL1_INPUTB_P2_3              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL1_INPUTB_VADC0_G1BFLOUT1   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL2_INPUTA_ACMP2_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL2_INPUTA_ACMP4_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL2_INPUTA_P2_6              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL2_INPUTA_VADC0_G0BFLOUT2   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL2_INPUTB_ACMP2_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL2_INPUTB_P2_10             	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL2_INPUTB_P2_11             	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL2_INPUTB_VADC0_G1BFLOUT2   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL3_INPUTA_ACMP5_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL3_INPUTA_ACMP7_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL3_INPUTA_P2_7              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL3_INPUTA_VADC0_G0BFLOUT3   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL3_INPUTB_ACMP6_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL3_INPUTB_P2_8              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL3_INPUTB_P2_9              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL3_INPUTB_VADC0_G1BFLOUT3   	XMC_ERU_ETL_INPUT_B3

#define ERU0_OGU0_PERIPHERAL_TRIGGER_CCU40_SR0	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU0_PERIPHERAL_TRIGGER_VADC_C0SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU1_PERIPHERAL_TRIGGER_CCU40_SR1	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU1_PERIPHERAL_TRIGGER_VADC_C0SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU2_PERIPHERAL_TRIGGER_CCU40_SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU2_PERIPHERAL_TRIGGER_VADC_C0SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU3_PERIPHERAL_TRIGGER_CCU40_SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU3_PERIPHERAL_TRIGGER_VADC_C0SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#endif


#if (UC_DEVICE == XMC1202) && (UC_PACKAGE == TSSOP16)
#define ERU0_ETL0_INPUTA_ACMP0_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL0_INPUTA_ACMP2_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL0_INPUTA_VADC0_G0BFLOUT0   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL0_INPUTB_ACMP0_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL0_INPUTB_P2_0              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL0_INPUTB_VADC0_G1BFLOUT0   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL1_INPUTA_ACMP1_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL1_INPUTA_ACMP3_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL1_INPUTA_VADC0_G0BFLOUT1   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL1_INPUTB_ACMP1_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL1_INPUTB_VADC0_G1BFLOUT1   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL2_INPUTA_ACMP4_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL2_INPUTA_P2_6              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL2_INPUTA_VADC0_G0BFLOUT2   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL2_INPUTB_ACMP2_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL2_INPUTB_P2_10             	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL2_INPUTB_P2_11             	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL2_INPUTB_VADC0_G1BFLOUT2   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL3_INPUTA_ACMP5_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL3_INPUTA_ACMP7_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL3_INPUTA_P2_7              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL3_INPUTA_VADC0_G0BFLOUT3   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL3_INPUTB_ACMP6_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL3_INPUTB_P2_8              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL3_INPUTB_P2_9              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL3_INPUTB_VADC0_G1BFLOUT3   	XMC_ERU_ETL_INPUT_B3

#define ERU0_OGU0_PERIPHERAL_TRIGGER_CCU40_SR0	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU0_PERIPHERAL_TRIGGER_VADC_C0SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU1_PERIPHERAL_TRIGGER_CCU40_SR1	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU1_PERIPHERAL_TRIGGER_VADC_C0SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU2_PERIPHERAL_TRIGGER_CCU40_SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU2_PERIPHERAL_TRIGGER_VADC_C0SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU3_PERIPHERAL_TRIGGER_CCU40_SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU3_PERIPHERAL_TRIGGER_VADC_C0SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#endif


#if (UC_DEVICE == XMC1202) && (UC_PACKAGE == TSSOP28)
#define ERU0_ETL0_INPUTA_ACMP0_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL0_INPUTA_ACMP2_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL0_INPUTA_VADC0_G0BFLOUT0   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL0_INPUTB_ACMP0_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL0_INPUTB_P2_0              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL0_INPUTB_P2_2              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL0_INPUTB_VADC0_G1BFLOUT0   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL1_INPUTA_ACMP1_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL1_INPUTA_ACMP3_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL1_INPUTA_P2_5              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL1_INPUTA_VADC0_G0BFLOUT1   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL1_INPUTB_ACMP1_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL1_INPUTB_P2_1              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL1_INPUTB_VADC0_G1BFLOUT1   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL2_INPUTA_ACMP2_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL2_INPUTA_ACMP4_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL2_INPUTA_P2_6              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL2_INPUTA_VADC0_G0BFLOUT2   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL2_INPUTB_ACMP2_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL2_INPUTB_P2_10             	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL2_INPUTB_P2_11             	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL2_INPUTB_VADC0_G1BFLOUT2   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL3_INPUTA_ACMP5_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL3_INPUTA_ACMP7_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL3_INPUTA_P2_7              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL3_INPUTA_VADC0_G0BFLOUT3   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL3_INPUTB_ACMP6_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL3_INPUTB_P2_8              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL3_INPUTB_P2_9              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL3_INPUTB_VADC0_G1BFLOUT3   	XMC_ERU_ETL_INPUT_B3

#define ERU0_OGU0_PERIPHERAL_TRIGGER_CCU40_SR0	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU0_PERIPHERAL_TRIGGER_VADC_C0SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU1_PERIPHERAL_TRIGGER_CCU40_SR1	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU1_PERIPHERAL_TRIGGER_VADC_C0SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU2_PERIPHERAL_TRIGGER_CCU40_SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU2_PERIPHERAL_TRIGGER_VADC_C0SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU3_PERIPHERAL_TRIGGER_CCU40_SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU3_PERIPHERAL_TRIGGER_VADC_C0SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#endif


#if (UC_DEVICE == XMC1301) && (UC_PACKAGE == VQFN24)
#define ERU0_ETL0_INPUTA_ACMP0_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL0_INPUTA_ACMP2_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL0_INPUTA_VADC0_G0BFLOUT0   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL0_INPUTB_ACMP0_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL0_INPUTB_P2_0              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL0_INPUTB_P2_2              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL0_INPUTB_VADC0_G1BFLOUT0   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL1_INPUTA_ACMP1_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL1_INPUTA_ACMP3_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL1_INPUTA_VADC0_G0BFLOUT1   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL1_INPUTB_ACMP1_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL1_INPUTB_P2_1              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL1_INPUTB_VADC0_G1BFLOUT1   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL2_INPUTA_ACMP2_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL2_INPUTA_ACMP4_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL2_INPUTA_P2_6              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL2_INPUTA_VADC0_G0BFLOUT2   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL2_INPUTB_ACMP2_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL2_INPUTB_P2_10             	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL2_INPUTB_P2_11             	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL2_INPUTB_VADC0_G1BFLOUT2   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL3_INPUTA_ACMP5_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL3_INPUTA_ACMP7_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL3_INPUTA_P2_7              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL3_INPUTA_VADC0_G0BFLOUT3   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL3_INPUTB_ACMP6_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL3_INPUTB_P2_8              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL3_INPUTB_P2_9              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL3_INPUTB_VADC0_G1BFLOUT3   	XMC_ERU_ETL_INPUT_B3

#define ERU0_OGU0_PERIPHERAL_TRIGGER_CCU40_SR0	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU0_PERIPHERAL_TRIGGER_CCU80_SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER3
#define ERU0_OGU0_PERIPHERAL_TRIGGER_VADC_C0SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU1_PERIPHERAL_TRIGGER_CCU40_SR1	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU1_PERIPHERAL_TRIGGER_CCU80_SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER3
#define ERU0_OGU1_PERIPHERAL_TRIGGER_VADC_C0SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU2_PERIPHERAL_TRIGGER_CCU40_SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU2_PERIPHERAL_TRIGGER_CCU80_SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER3
#define ERU0_OGU2_PERIPHERAL_TRIGGER_VADC_C0SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU3_PERIPHERAL_TRIGGER_CCU40_SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU3_PERIPHERAL_TRIGGER_CCU80_SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER3
#define ERU0_OGU3_PERIPHERAL_TRIGGER_VADC_C0SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#endif


#if (UC_DEVICE == XMC1301) && (UC_PACKAGE == VQFN40)
#define ERU0_ETL0_INPUTA_ACMP0_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL0_INPUTA_ACMP2_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL0_INPUTA_P2_4              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL0_INPUTA_VADC0_G0BFLOUT0   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL0_INPUTB_ACMP0_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL0_INPUTB_P2_0              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL0_INPUTB_P2_2              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL0_INPUTB_VADC0_G1BFLOUT0   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL1_INPUTA_ACMP1_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL1_INPUTA_ACMP3_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL1_INPUTA_P2_5              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL1_INPUTA_VADC0_G0BFLOUT1   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL1_INPUTB_ACMP1_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL1_INPUTB_P2_1              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL1_INPUTB_P2_3              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL1_INPUTB_VADC0_G1BFLOUT1   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL2_INPUTA_ACMP2_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL2_INPUTA_ACMP4_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL2_INPUTA_P2_6              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL2_INPUTA_VADC0_G0BFLOUT2   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL2_INPUTB_ACMP2_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL2_INPUTB_P2_10             	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL2_INPUTB_P2_11             	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL2_INPUTB_VADC0_G1BFLOUT2   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL3_INPUTA_ACMP5_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL3_INPUTA_ACMP7_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL3_INPUTA_P2_7              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL3_INPUTA_VADC0_G0BFLOUT3   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL3_INPUTB_ACMP6_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL3_INPUTB_P2_8              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL3_INPUTB_P2_9              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL3_INPUTB_VADC0_G1BFLOUT3   	XMC_ERU_ETL_INPUT_B3

#define ERU0_OGU0_PERIPHERAL_TRIGGER_CCU40_SR0	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU0_PERIPHERAL_TRIGGER_CCU80_SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER3
#define ERU0_OGU0_PERIPHERAL_TRIGGER_VADC_C0SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU1_PERIPHERAL_TRIGGER_CCU40_SR1	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU1_PERIPHERAL_TRIGGER_CCU80_SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER3
#define ERU0_OGU1_PERIPHERAL_TRIGGER_VADC_C0SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU2_PERIPHERAL_TRIGGER_CCU40_SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU2_PERIPHERAL_TRIGGER_CCU80_SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER3
#define ERU0_OGU2_PERIPHERAL_TRIGGER_VADC_C0SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU3_PERIPHERAL_TRIGGER_CCU40_SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU3_PERIPHERAL_TRIGGER_CCU80_SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER3
#define ERU0_OGU3_PERIPHERAL_TRIGGER_VADC_C0SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#endif


#if (UC_DEVICE == XMC1301) && (UC_PACKAGE == TSSOP16)
#define ERU0_ETL0_INPUTA_ACMP0_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL0_INPUTA_ACMP2_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL0_INPUTA_VADC0_G0BFLOUT0   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL0_INPUTB_ACMP0_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL0_INPUTB_P2_0              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL0_INPUTB_VADC0_G1BFLOUT0   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL1_INPUTA_ACMP1_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL1_INPUTA_ACMP3_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL1_INPUTA_VADC0_G0BFLOUT1   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL1_INPUTB_ACMP1_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL1_INPUTB_VADC0_G1BFLOUT1   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL2_INPUTA_ACMP4_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL2_INPUTA_P2_6              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL2_INPUTA_VADC0_G0BFLOUT2   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL2_INPUTB_ACMP2_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL2_INPUTB_P2_10             	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL2_INPUTB_P2_11             	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL2_INPUTB_VADC0_G1BFLOUT2   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL3_INPUTA_ACMP5_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL3_INPUTA_ACMP7_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL3_INPUTA_P2_7              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL3_INPUTA_VADC0_G0BFLOUT3   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL3_INPUTB_ACMP6_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL3_INPUTB_P2_8              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL3_INPUTB_P2_9              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL3_INPUTB_VADC0_G1BFLOUT3   	XMC_ERU_ETL_INPUT_B3

#define ERU0_OGU0_PERIPHERAL_TRIGGER_CCU40_SR0	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU0_PERIPHERAL_TRIGGER_CCU80_SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER3
#define ERU0_OGU0_PERIPHERAL_TRIGGER_VADC_C0SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU1_PERIPHERAL_TRIGGER_CCU40_SR1	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU1_PERIPHERAL_TRIGGER_CCU80_SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER3
#define ERU0_OGU1_PERIPHERAL_TRIGGER_VADC_C0SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU2_PERIPHERAL_TRIGGER_CCU40_SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU2_PERIPHERAL_TRIGGER_CCU80_SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER3
#define ERU0_OGU2_PERIPHERAL_TRIGGER_VADC_C0SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU3_PERIPHERAL_TRIGGER_CCU40_SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU3_PERIPHERAL_TRIGGER_CCU80_SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER3
#define ERU0_OGU3_PERIPHERAL_TRIGGER_VADC_C0SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#endif


#if (UC_DEVICE == XMC1301) && (UC_PACKAGE == TSSOP38)
#define ERU0_ETL0_INPUTA_ACMP0_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL0_INPUTA_ACMP2_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL0_INPUTA_P2_4              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL0_INPUTA_VADC0_G0BFLOUT0   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL0_INPUTB_ACMP0_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL0_INPUTB_P2_0              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL0_INPUTB_P2_2              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL0_INPUTB_VADC0_G1BFLOUT0   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL1_INPUTA_ACMP1_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL1_INPUTA_ACMP3_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL1_INPUTA_P2_5              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL1_INPUTA_VADC0_G0BFLOUT1   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL1_INPUTB_ACMP1_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL1_INPUTB_P2_1              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL1_INPUTB_P2_3              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL1_INPUTB_VADC0_G1BFLOUT1   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL2_INPUTA_ACMP2_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL2_INPUTA_ACMP4_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL2_INPUTA_P2_6              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL2_INPUTA_VADC0_G0BFLOUT2   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL2_INPUTB_ACMP2_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL2_INPUTB_P2_10             	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL2_INPUTB_P2_11             	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL2_INPUTB_VADC0_G1BFLOUT2   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL3_INPUTA_ACMP5_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL3_INPUTA_ACMP7_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL3_INPUTA_P2_7              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL3_INPUTA_VADC0_G0BFLOUT3   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL3_INPUTB_ACMP6_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL3_INPUTB_P2_8              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL3_INPUTB_P2_9              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL3_INPUTB_VADC0_G1BFLOUT3   	XMC_ERU_ETL_INPUT_B3

#define ERU0_OGU0_PERIPHERAL_TRIGGER_CCU40_SR0	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU0_PERIPHERAL_TRIGGER_CCU80_SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER3
#define ERU0_OGU0_PERIPHERAL_TRIGGER_VADC_C0SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU1_PERIPHERAL_TRIGGER_CCU40_SR1	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU1_PERIPHERAL_TRIGGER_CCU80_SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER3
#define ERU0_OGU1_PERIPHERAL_TRIGGER_VADC_C0SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU2_PERIPHERAL_TRIGGER_CCU40_SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU2_PERIPHERAL_TRIGGER_CCU80_SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER3
#define ERU0_OGU2_PERIPHERAL_TRIGGER_VADC_C0SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU3_PERIPHERAL_TRIGGER_CCU40_SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU3_PERIPHERAL_TRIGGER_CCU80_SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER3
#define ERU0_OGU3_PERIPHERAL_TRIGGER_VADC_C0SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#endif


#if (UC_DEVICE == XMC1302) && (UC_PACKAGE == VQFN24)
#define ERU0_ETL0_INPUTA_ACMP0_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL0_INPUTA_ACMP2_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL0_INPUTA_VADC0_G0BFLOUT0   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL0_INPUTB_ACMP0_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL0_INPUTB_P2_0              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL0_INPUTB_P2_2              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL0_INPUTB_VADC0_G1BFLOUT0   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL1_INPUTA_ACMP1_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL1_INPUTA_ACMP3_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL1_INPUTA_VADC0_G0BFLOUT1   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL1_INPUTB_ACMP1_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL1_INPUTB_P2_1              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL1_INPUTB_VADC0_G1BFLOUT1   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL2_INPUTA_ACMP2_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL2_INPUTA_ACMP4_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL2_INPUTA_P2_6              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL2_INPUTA_VADC0_G0BFLOUT2   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL2_INPUTB_ACMP2_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL2_INPUTB_P2_10             	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL2_INPUTB_P2_11             	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL2_INPUTB_VADC0_G1BFLOUT2   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL3_INPUTA_ACMP5_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL3_INPUTA_ACMP7_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL3_INPUTA_P2_7              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL3_INPUTA_VADC0_G0BFLOUT3   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL3_INPUTB_ACMP6_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL3_INPUTB_P2_8              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL3_INPUTB_P2_9              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL3_INPUTB_VADC0_G1BFLOUT3   	XMC_ERU_ETL_INPUT_B3

#define ERU0_OGU0_PERIPHERAL_TRIGGER_CCU40_SR0	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU0_PERIPHERAL_TRIGGER_CCU80_SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER3
#define ERU0_OGU0_PERIPHERAL_TRIGGER_VADC_C0SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU1_PERIPHERAL_TRIGGER_CCU40_SR1	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU1_PERIPHERAL_TRIGGER_CCU80_SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER3
#define ERU0_OGU1_PERIPHERAL_TRIGGER_VADC_C0SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU2_PERIPHERAL_TRIGGER_CCU40_SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU2_PERIPHERAL_TRIGGER_CCU80_SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER3
#define ERU0_OGU2_PERIPHERAL_TRIGGER_VADC_C0SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU3_PERIPHERAL_TRIGGER_CCU40_SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU3_PERIPHERAL_TRIGGER_CCU80_SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER3
#define ERU0_OGU3_PERIPHERAL_TRIGGER_VADC_C0SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#endif


#if (UC_DEVICE == XMC1302) && (UC_PACKAGE == VQFN40)
#define ERU0_ETL0_INPUTA_ACMP0_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL0_INPUTA_ACMP2_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL0_INPUTA_P2_4              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL0_INPUTA_VADC0_G0BFLOUT0   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL0_INPUTB_ACMP0_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL0_INPUTB_P2_0              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL0_INPUTB_P2_2              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL0_INPUTB_VADC0_G1BFLOUT0   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL1_INPUTA_ACMP1_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL1_INPUTA_ACMP3_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL1_INPUTA_P2_5              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL1_INPUTA_VADC0_G0BFLOUT1   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL1_INPUTB_ACMP1_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL1_INPUTB_P2_1              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL1_INPUTB_P2_3              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL1_INPUTB_VADC0_G1BFLOUT1   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL2_INPUTA_ACMP2_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL2_INPUTA_ACMP4_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL2_INPUTA_P2_6              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL2_INPUTA_VADC0_G0BFLOUT2   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL2_INPUTB_ACMP2_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL2_INPUTB_P2_10             	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL2_INPUTB_P2_11             	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL2_INPUTB_VADC0_G1BFLOUT2   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL3_INPUTA_ACMP5_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL3_INPUTA_ACMP7_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL3_INPUTA_P2_7              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL3_INPUTA_VADC0_G0BFLOUT3   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL3_INPUTB_ACMP6_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL3_INPUTB_P2_8              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL3_INPUTB_P2_9              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL3_INPUTB_VADC0_G1BFLOUT3   	XMC_ERU_ETL_INPUT_B3

#define ERU0_OGU0_PERIPHERAL_TRIGGER_CCU40_SR0	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU0_PERIPHERAL_TRIGGER_CCU80_SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER3
#define ERU0_OGU0_PERIPHERAL_TRIGGER_VADC_C0SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU1_PERIPHERAL_TRIGGER_CCU40_SR1	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU1_PERIPHERAL_TRIGGER_CCU80_SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER3
#define ERU0_OGU1_PERIPHERAL_TRIGGER_VADC_C0SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU2_PERIPHERAL_TRIGGER_CCU40_SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU2_PERIPHERAL_TRIGGER_CCU80_SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER3
#define ERU0_OGU2_PERIPHERAL_TRIGGER_VADC_C0SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU3_PERIPHERAL_TRIGGER_CCU40_SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU3_PERIPHERAL_TRIGGER_CCU80_SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER3
#define ERU0_OGU3_PERIPHERAL_TRIGGER_VADC_C0SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#endif


#if (UC_DEVICE == XMC1302) && (UC_PACKAGE == TSSOP16)
#define ERU0_ETL0_INPUTA_ACMP0_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL0_INPUTA_ACMP2_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL0_INPUTA_VADC0_G0BFLOUT0   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL0_INPUTB_ACMP0_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL0_INPUTB_P2_0              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL0_INPUTB_VADC0_G1BFLOUT0   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL1_INPUTA_ACMP1_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL1_INPUTA_ACMP3_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL1_INPUTA_VADC0_G0BFLOUT1   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL1_INPUTB_ACMP1_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL1_INPUTB_VADC0_G1BFLOUT1   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL2_INPUTA_ACMP2_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL2_INPUTA_ACMP4_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL2_INPUTA_P2_6              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL2_INPUTA_VADC0_G0BFLOUT2   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL2_INPUTB_ACMP2_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL2_INPUTB_P2_10             	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL2_INPUTB_P2_11             	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL2_INPUTB_VADC0_G1BFLOUT2   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL3_INPUTA_ACMP5_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL3_INPUTA_ACMP7_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL3_INPUTA_P2_7              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL3_INPUTA_VADC0_G0BFLOUT3   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL3_INPUTB_ACMP6_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL3_INPUTB_P2_8              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL3_INPUTB_P2_9              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL3_INPUTB_VADC0_G1BFLOUT3   	XMC_ERU_ETL_INPUT_B3

#define ERU0_OGU0_PERIPHERAL_TRIGGER_CCU40_SR0	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU0_PERIPHERAL_TRIGGER_CCU80_SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER3
#define ERU0_OGU0_PERIPHERAL_TRIGGER_VADC_C0SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU1_PERIPHERAL_TRIGGER_CCU40_SR1	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU1_PERIPHERAL_TRIGGER_CCU80_SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER3
#define ERU0_OGU1_PERIPHERAL_TRIGGER_VADC_C0SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU2_PERIPHERAL_TRIGGER_CCU40_SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU2_PERIPHERAL_TRIGGER_CCU80_SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER3
#define ERU0_OGU2_PERIPHERAL_TRIGGER_VADC_C0SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU3_PERIPHERAL_TRIGGER_CCU40_SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU3_PERIPHERAL_TRIGGER_CCU80_SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER3
#define ERU0_OGU3_PERIPHERAL_TRIGGER_VADC_C0SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#endif


#if (UC_DEVICE == XMC1302) && (UC_PACKAGE == TSSOP38)
#define ERU0_ETL0_INPUTA_ACMP0_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL0_INPUTA_ACMP2_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL0_INPUTA_P2_4              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL0_INPUTA_VADC0_G0BFLOUT0   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL0_INPUTB_ACMP0_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL0_INPUTB_P2_0              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL0_INPUTB_P2_2              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL0_INPUTB_VADC0_G1BFLOUT0   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL1_INPUTA_ACMP1_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL1_INPUTA_ACMP3_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL1_INPUTA_P2_5              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL1_INPUTA_VADC0_G0BFLOUT1   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL1_INPUTB_ACMP1_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL1_INPUTB_P2_1              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL1_INPUTB_P2_3              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL1_INPUTB_VADC0_G1BFLOUT1   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL2_INPUTA_ACMP2_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL2_INPUTA_ACMP4_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL2_INPUTA_P2_6              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL2_INPUTA_VADC0_G0BFLOUT2   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL2_INPUTB_ACMP2_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL2_INPUTB_P2_10             	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL2_INPUTB_P2_11             	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL2_INPUTB_VADC0_G1BFLOUT2   	XMC_ERU_ETL_INPUT_B3
#define ERU0_ETL3_INPUTA_ACMP5_OUT         	XMC_ERU_ETL_INPUT_A2
#define ERU0_ETL3_INPUTA_ACMP7_OUT         	XMC_ERU_ETL_INPUT_A0
#define ERU0_ETL3_INPUTA_P2_7              	XMC_ERU_ETL_INPUT_A1
#define ERU0_ETL3_INPUTA_VADC0_G0BFLOUT3   	XMC_ERU_ETL_INPUT_A3
#define ERU0_ETL3_INPUTB_ACMP6_OUT         	XMC_ERU_ETL_INPUT_B2
#define ERU0_ETL3_INPUTB_P2_8              	XMC_ERU_ETL_INPUT_B1
#define ERU0_ETL3_INPUTB_P2_9              	XMC_ERU_ETL_INPUT_B0
#define ERU0_ETL3_INPUTB_VADC0_G1BFLOUT3   	XMC_ERU_ETL_INPUT_B3

#define ERU0_OGU0_PERIPHERAL_TRIGGER_CCU40_SR0	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU0_PERIPHERAL_TRIGGER_CCU80_SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER3
#define ERU0_OGU0_PERIPHERAL_TRIGGER_VADC_C0SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU1_PERIPHERAL_TRIGGER_CCU40_SR1	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU1_PERIPHERAL_TRIGGER_CCU80_SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER3
#define ERU0_OGU1_PERIPHERAL_TRIGGER_VADC_C0SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU2_PERIPHERAL_TRIGGER_CCU40_SR2	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU2_PERIPHERAL_TRIGGER_CCU80_SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER3
#define ERU0_OGU2_PERIPHERAL_TRIGGER_VADC_C0SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#define ERU0_OGU3_PERIPHERAL_TRIGGER_CCU40_SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER1
#define ERU0_OGU3_PERIPHERAL_TRIGGER_CCU80_SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER3
#define ERU0_OGU3_PERIPHERAL_TRIGGER_VADC_C0SR3	XMC_ERU_OGU_PERIPHERAL_TRIGGER2
#endif

#endif /* XMC1_ERU_MAP_H */
